@@ -3,9 +3,7 @@
 """ Filter Selected Regression Tests based on User-Supplied Criteria """
 
 
-from baseblock import EnvIO
-from baseblock import Stopwatch
-from baseblock import BaseObject
+from baseblock import BaseObject, EnvIO, Stopwatch
 
 
 class FilterRegressionTests(BaseObject):
